import json
import logging
from datetime import date
from typing import Annotated, Any

from fastapi import FastAPI, File, UploadFile
from ironhide import BaseAgent, tool
from ironhide.settings import settings
from pydantic import BaseModel, Field

app = FastAPI()

logging.basicConfig(
    level=settings.log_level,
    format="%(asctime)s  %(levelname)s  %(filename)s  %(funcName)s  %(message)s",
)


class Request(BaseModel):
    """User Message to Agent."""

    content: str


class Image(BaseAgent):
    instructions = """You are an expert at extracting text from images and converting it into structured data. 
    Your task is to:
    1. First, carefully read and extract all text visible in the provided image
    2. Then, analyze the extracted text to identify relevant information
    3. Finally, convert the information into the requested structured format
    Be thorough in your text extraction and precise in your data structuring."""


agent = Image()


@app.post("/")
async def agent_message(
    file: Annotated[UploadFile, File()],
) -> BaseModel | str:
    """Extract text from image and convert to structured data."""
    contents = await file.read()
    files = {"file": (file.filename, contents, file.content_type)}
    return await agent.chat("Extract the text from the image", files=files)



import json
import logging
from datetime import date
from typing import Annotated, Any

from fastapi import FastAPI
from ironhide import BaseAgent, tool
from ironhide.settings import settings
from pydantic import BaseModel, Field

app = FastAPI()

logging.basicConfig(
    level=settings.log_level,
    format="%(asctime)s  %(levelname)s  %(filename)s  %(funcName)s  %(message)s",
)


class Request(BaseModel):
    """User Message to Agent."""

    content: str


class Contrato(BaseModel):
    indice_de_reajuste: str = Field(
        description="Índice usado para reajuste do contrato",
    )
    data_reajuste_contrato: str = Field(
        description="Data de reajuste do contrato",
    )
    data_inicio_validade_contrato: date = Field(
        description="Data de início da validade do contrato",
    )
    data_fim_validade_contrato: date = Field(
        description="Data de término da validade do contrato",
    )
    prazo_da_locacao_em_meses: int = Field(
        description="Duração do contrato em meses",
    )
    dobra_no_mes_dezembro: bool = Field(
        description="Indica se há valor dobrado em dezembro",
    )


class Imovel(BaseModel):
    valor_aluguel_em_reais: str = Field(
        description="Valor do aluguel em reais",
    )


class Dados(BaseModel):
    contrato: Contrato = Field(
        description="Informações do contrato",
    )
    imovel: Imovel = Field(
        description="Informações do imóvel",
    )


class Extractor(BaseAgent):
    instructions = "You are an expert at structured data extraction. You will be given unstructured text and should convert it into the given structure."

    chain_of_thought = (
        "[thought] Analise cada um dos campos requisitados com base no texto fornecido.",
    )


agent = Extractor()


@app.post("/")
async def agent_message(
    message: Request,
) -> Dados | BaseModel | str:
    """Get response from agent."""
    return await agent.chat(message.content, response_format=Dados)
